# Generated by roxygen2: do not edit by hand

S3method(coef,jointCovariance)
S3method(jointCovariance,default)
S3method(plot,pated)
S3method(print,summary.jointCovariance)
S3method(summary,jointCovariance)
S3method(vcov,jointCovariance)
export(coxph_)
export(gee_)
export(glm_)
export(jointCovariance)
export(km_)
export(logrank_)
export(mmrm_)
export(pated)
export(quantile_)
export(simulateMoData)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_step)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,ylim)
importFrom(ggpubr,ggarrange)
importFrom(mvtnorm,rmvnorm)
importFrom(rlang,.data)
importFrom(sandwich,bread)
importFrom(sandwich,estfun)
importFrom(stats,coef)
importFrom(stats,cov)
importFrom(stats,cov2cor)
importFrom(stats,gaussian)
importFrom(stats,model.extract)
importFrom(stats,model.matrix)
importFrom(stats,pchisq)
importFrom(stats,printCoefmat)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,resid)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,time)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(stringr,str_extract)
importFrom(stringr,str_glue)
importFrom(survival,strata)
importFrom(survival,survfit)
importFrom(tidyr,pivot_longer)
importFrom(tidyselect,all_of)
importFrom(utils,capture.output)
useDynLib(multipleOutcomes, .registration = TRUE)
