#' @importFrom ggplot2 ggplot aes geom_point geom_abline geom_ribbon geom_step
#' @importFrom ggplot2 scale_x_continuous labs theme_minimal ylim
#' @importFrom mvtnorm rmvnorm
#' @importFrom tidyr pivot_longer
#' @importFrom survival survfit strata
#' @importFrom dplyr "%>%" select mutate
#' @importFrom tidyselect all_of
#' @importFrom rlang .data
#' @importFrom stringr str_glue
#' @importFrom stats model.matrix resid
#' @importFrom sandwich estfun bread
NULL
